==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/projectexplorer/allprojectsfilter.cpp <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "allprojectsfilter.h"
#include "projectexplorer.h"
#include "session.h"
#include "project.h"

using namespace Core;
using namespace Locator;
using namespace ProjectExplorer;
using namespace ProjectExplorer::Internal;

AllProjectsFilter::AllProjectsFilter() : m_filesUpToDate(false)
{
    setId("Files in any project");
    setDisplayName(tr("Files in Any Project"));
    setShortcutString(QString(QLatin1Char('a')));
    setPriority(Low);
    setIncludedByDefault(true);

    connect(ProjectExplorerPlugin::instance(), SIGNAL(fileListChanged()),
            this, SLOT(markFilesAsOutOfDate()));
}

void AllProjectsFilter::markFilesAsOutOfDate()
{
    m_filesUpToDate = false;
}

void AllProjectsFilter::updateFiles()
{
    if (m_filesUpToDate)
        return;
    m_filesUpToDate = true;
    files().clear();
    foreach (Project *project, SessionManager::projects())
        files().append(project->files(Project::AllFiles));
    qSort(files());
    generateFileNames();
}

void AllProjectsFilter::refresh(QFutureInterface<void> &future)
{
    Q_UNUSED(future)
    QMetaObject::invokeMethod(this, "markFilesAsOutOfDate", Qt::BlockingQueuedConnection);
}

==> qt-creator-opensource-src-3.2.2.zip: qt-creator-opensource-src-3.2.2/src/plugins/projectexplorer/allprojectsfilter.cpp <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "allprojectsfilter.h"
#include "projectexplorer.h"
#include "session.h"
#include "project.h"

#include <utils/algorithm.h>

using namespace Core;
using namespace ProjectExplorer;
using namespace ProjectExplorer::Internal;

AllProjectsFilter::AllProjectsFilter() : m_filesUpToDate(false)
{
    setId("Files in any project");
    setDisplayName(tr("Files in Any Project"));
    setShortcutString(QString(QLatin1Char('a')));
    setPriority(Low);
    setIncludedByDefault(true);

    connect(ProjectExplorerPlugin::instance(), SIGNAL(fileListChanged()),
            this, SLOT(markFilesAsOutOfDate()));
}

void AllProjectsFilter::markFilesAsOutOfDate()
{
    m_filesUpToDate = false;
}

void AllProjectsFilter::updateFilesImpl()
{
    if (m_filesUpToDate)
        return;
    files().clear();
    foreach (Project *project, SessionManager::projects())
        files().append(project->files(Project::AllFiles));
    Utils::sort(files());
    generateFileNames();
    m_filesUpToDate = true;
}

void AllProjectsFilter::updateFiles()
{
    QMetaObject::invokeMethod(this, "updateFilesImpl", Qt::BlockingQueuedConnection);
}

void AllProjectsFilter::refresh(QFutureInterface<void> &future)
{
    Q_UNUSED(future)
    QMetaObject::invokeMethod(this, "markFilesAsOutOfDate", Qt::BlockingQueuedConnection);
}
